@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for appsync service client
 
@@ -10,10 +11,12 @@ Usage::
     client: AppSyncClient = boto3.client("appsync")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
+from typing import IO, Any, Dict, List, Type, Union, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_appsync.paginator import (
     ListApiKeysPaginator,
     ListDataSourcesPaginator,
@@ -535,3 +538,6 @@ class AppSyncClient:
         """
         [Paginator.ListTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/appsync.html#AppSync.Paginator.ListTypes)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
