@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for appsync service client paginators.
 
@@ -28,10 +29,11 @@ Usage::
     list_types_paginator: ListTypesPaginator = client.get_paginator("list_types")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_appsync.type_defs import (
     ListApiKeysResponseTypeDef,
     ListDataSourcesResponseTypeDef,
